# Types

## Shape Types
::: fdtdx.core.jax.typing.RealShape3D
::: fdtdx.core.jax.typing.PartialRealShape3D
::: fdtdx.core.jax.typing.GridShape3D
::: fdtdx.core.jax.typing.PartialGridShape3D

## Slice Types
::: fdtdx.core.jax.typing.SliceTuple3D
::: fdtdx.core.jax.typing.PartialSliceTuple3D
::: fdtdx.core.jax.typing.Slice3D
::: fdtdx.core.jax.typing.PartialSlice3D
